pub enum CallError {
ArgumentEncoding(Error),
Reject(RejectResponse),
ResultDecoding(Error),
}Expand description
Errors that can occur during a canister method call.
Variants
ArgumentEncoding(Error)
Error during argument encoding (Candid serialization).
Reject(RejectResponse)
The canister rejected the call, providing a rejection message and error code.
ResultDecoding(Error)
Error during decoding the response (Candid deserialization).